@@ -1,13 +1,13 @@
-x1 <- gss[1:100,] %>% specify(response = hours)
-x2 <- gss[1:100,] %>% specify(hours ~ NULL)
-x3 <- gss[1:100,] %>% specify(response = hours, explanatory = c(age, college))
-x4 <- gss[1:100,] %>% specify(hours ~ age + college)
+x1 <- gss[1:100, ] |> specify(response = hours)
+x2 <- gss[1:100, ] |> specify(hours ~ NULL)
+x3 <- gss[1:100, ] |> specify(response = hours, explanatory = c(age, college))
+x4 <- gss[1:100, ] |> specify(hours ~ age + college)
 
 test_that("get_formula helper works", {
   expect_false(has_attr(x1, "formula"))
-  expect_true(has_attr( x2, "formula"))
+  expect_true(has_attr(x2, "formula"))
   expect_false(has_attr(x3, "formula"))
-  expect_true(has_attr( x4, "formula"))
+  expect_true(has_attr(x4, "formula"))
 
   expect_equal(get_formula(x1), get_formula(x2), ignore_attr = TRUE)
   expect_equal(get_formula(x3), get_formula(x4), ignore_attr = TRUE)
@@ -37,7 +37,7 @@ test_that("fit_linear_model helper works", {
 
   expect_equal(
     c("character", "numeric"),
-    purrr::map_chr(x3_m, class) %>% unname()
+    purrr::map_chr(x3_m, class) |> unname()
   )
 
   expect_equal(
@@ -47,11 +47,11 @@ test_that("fit_linear_model helper works", {
 })
 
 test_that("fit.infer can handle generated objects", {
-  x3_fit <- x3 %>% fit()
+  x3_fit <- x3 |> fit()
 
-  x3_gen_fit <- x3 %>%
-    hypothesize(null = 'independence') %>%
-    generate(reps = 2, type = "permute")%>%
+  x3_gen_fit <- x3 |>
+    hypothesize(null = 'independence') |>
+    generate(reps = 2, type = "permute") |>
     fit()
 
   expect_equal(unique(x3_fit$term), unique(x3_gen_fit$term))
@@ -66,15 +66,15 @@ test_that("fit.infer can handle generated objects", {
 
 test_that("fit.infer messages informatively on excessive null", {
   expect_snapshot(
-    res_ <- gss %>%
-      specify(hours ~ age + college) %>%
-      hypothesize(null = "independence") %>%
+    res_ <- gss |>
+      specify(hours ~ age + college) |>
+      hypothesize(null = "independence") |>
       fit()
   )
 
   expect_silent(
-    gss %>%
-      specify(hours ~ age + college) %>%
+    gss |>
+      specify(hours ~ age + college) |>
       fit()
   )
 })
@@ -82,52 +82,53 @@ test_that("fit.infer messages informatively on excessive null", {
 test_that("fit.infer logistic regression works", {
   # linear regression default works
   expect_equal(
-    gss %>%
-      specify(hours ~ age + college) %>%
+    gss |>
+      specify(hours ~ age + college) |>
       fit(),
-    gss %>%
-      specify(hours ~ age + college) %>%
+    gss |>
+      specify(hours ~ age + college) |>
       fit(family = stats::gaussian)
   )
 
   # logistic regression default works
   expect_equal(
-    gss %>%
-      specify(college ~ age + hours) %>%
+    gss |>
+      specify(college ~ age + hours) |>
       fit(family = stats::binomial),
-    gss %>%
-      specify(college ~ age + hours) %>%
+    gss |>
+      specify(college ~ age + hours) |>
       fit()
   )
 
   # errors informatively with multinomial response variable
-  expect_snapshot(error = TRUE,
-    gss %>%
-      specify(finrela ~ age + college) %>%
+  expect_snapshot(
+    error = TRUE,
+    gss |>
+      specify(finrela ~ age + college) |>
       fit()
   )
 
   # works as expected for `generate()`d objects
-  fit_gen <- gss %>%
-    specify(college ~ age + hours) %>%
-    hypothesize(null = "independence") %>%
-    generate(type = "permute", reps = 2) %>%
+  fit_gen <- gss |>
+    specify(college ~ age + hours) |>
+    hypothesize(null = "independence") |>
+    generate(type = "permute", reps = 2) |>
     fit()
 
-  fit_obs <- gss %>%
-    specify(college ~ age + hours) %>%
+  fit_obs <- gss |>
+    specify(college ~ age + hours) |>
     fit()
 
   expect_equal(nrow(fit_gen), nrow(fit_obs) * 2)
   expect_equal(ncol(fit_gen), ncol(fit_obs) + 1)
 
   # responds to success argument
-  fit_deg <- gss %>%
-    specify(college ~ age + hours, success = "degree") %>%
+  fit_deg <- gss |>
+    specify(college ~ age + hours, success = "degree") |>
     fit()
 
-  fit_no_deg <- gss %>%
-    specify(college ~ age + hours, success = "no degree") %>%
+  fit_no_deg <- gss |>
+    specify(college ~ age + hours, success = "no degree") |>
     fit()
 
   expect_equal(fit_deg$term, fit_no_deg$term)
